/**
 * @module events
 */
import { Options } from './client.cjs';
import { GetProp } from '../server/interface.cjs';
import { Messages } from '../server/hot/Message.cjs';
export interface Events {
  ok(message: GetProp<Messages, 'ok'>, options: Options): void;
  hash(message: GetProp<Messages, 'hash'>, options: Options): void;
  issues(message: GetProp<Messages, 'issues'>, options: Options): void;
  invalid(message: GetProp<Messages, 'invalid'>, options: Options): void;
  progress(message: GetProp<Messages, 'progress'>, options: Options): void;
}
/**
 * @function on
 * @description Add an event listener callback.
 * @param event Event name.
 * @param callback Event listener callback.
 */
export declare function on<E extends keyof Events>(event: E, callback: GetProp<Events, E>): void;
/**
 * @function off
 * @description Remove an event listener callback.
 * @param event Event name.
 * @param callback Event listener callback.
 */
export declare function off<E extends keyof Events>(event: E, callback?: GetProp<Events, E>): void;
export declare function emit<E extends keyof Events>(event: E, message: GetProp<Messages, E>, options: Options): void;
