/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

'use strict';

const ready = require('./utils/ready.cjs');
const fs = require('./utils/fs.cjs');
const middleware = require('./middleware.cjs');
const utils = require('../utils.cjs');
const setupHooks = require('./utils/setupHooks.cjs');
const setupWatching = require('./utils/setupWatching.cjs');
const setupWriteToDisk = require('./utils/setupWriteToDisk.cjs');
const setupOutputFileSystem = require('./utils/setupOutputFileSystem.cjs');

/**
 * @module index
 */
function setup(compiler, options) {
  const context = {
    compiler,
    stats: null,
    callbacks: [],
    logger: compiler.getInfrastructureLogger(utils.PLUGIN_NAME),
    options: { fs: fs.createMemfs(), highWaterMark: 65536, ...options }
  };
  setupHooks.setupHooks(context);
  if (options.writeToDisk) {
    setupWriteToDisk.setupWriteToDisk(context);
  }
  setupOutputFileSystem.setupOutputFileSystem(context);
  setupWatching.setupWatching(context);
  return context;
}
function dev(compiler, options) {
  const context = setup(compiler, options);
  return Object.assign(middleware.middleware(context), {
    get state() {
      return !!context.stats;
    },
    get logger() {
      return context.logger;
    },
    ready(callback) {
      ready.ready(context, callback);
    },
    close(callback) {
      context.watching.close(callback);
    },
    invalidate(callback) {
      context.watching.invalidate(callback);
    }
  });
}

exports.dev = dev;
