/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

'use strict';

const memfs = require('memfs');

/**
 * @module fs
 */
/**
 * @function createMemfs
 * @description Create memfs instance.
 */
function createMemfs() {
  const volume = new memfs.Volume();
  return memfs.createFsFromVolume(volume);
}
/**
 * @function stat
 * @description Get file stats.
 * @param fs The file system to used.
 * @param path The file path.
 */
function stat(fs, path) {
  return new Promise(resolve => {
    fs.stat(path, (error, stats) => {
      resolve(error != null ? null : stats);
    });
  });
}

exports.createMemfs = createMemfs;
exports.stat = stat;
