/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

'use strict';

const node_crypto = require('node:crypto');

/**
 * @module hash
 */
// prettier-ignore
const CHARS = [
    // 0-9
    '0', '1', '2', '3', '4', '5', '6', '7', '8', '9',
    // A-M
    'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
    // N-Z
    'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z',
    // a-m
    'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm',
    // n-z
    'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z'
];
/**
 * @function generate
 * @description Generate a hash.
 * @param length The length of hash.
 */
function generate(length) {
  let hash = '';
  const randomValues = node_crypto.getRandomValues(new Uint8Array(length));
  // Create hash.
  for (const value of randomValues) {
    hash += CHARS[value % 62];
  }
  // Return hash.
  return hash;
}

exports.generate = generate;
