/**
 * @module http
 */
import { Context } from 'koa';
import { Stats } from 'node:fs';
import { Buffer } from 'node:buffer';
export interface Range {
  offset: number;
  length: number;
  prefix?: Buffer;
  suffix?: Buffer;
}
/**
 * @function decodeURI
 * @description Decode URI component.
 * @param URI The URI to decode.
 */
export declare function decodeURI(URI: string): string | -1;
/**
 * @function isConditionalGET
 * @description Check if request is conditional GET.
 * @param context The koa context.
 */
export declare function isConditionalGET({ request }: Context): boolean;
/**
 * @function isPreconditionFailed
 * @description Check if request precondition failed.
 * @param context The koa context.
 */
export declare function isPreconditionFailed({ request, response }: Context): boolean;
/**
 * @function parseRanges
 * @description Parse ranges.
 * @param context The koa context.
 * @param stats The file stats.
 */
export declare function parseRanges(context: Context, stats: Stats): Range[] | -1 | -2;
