/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

'use strict';

const node_url = require('node:url');

/**
 * @module paths
 */
function getStats(stats) {
  if ('stats' in stats) {
    return stats.stats;
  }
  // Return the stats.
  return [stats];
}
function getPublicPath(compilation) {
  const { publicPath } = compilation.outputOptions;
  // @see https://webpack.js.org/guides/public-path/#automatic-publicpath
  if (publicPath === 'auto') {
    return '/';
  }
  // Get public path.
  const path = compilation.getPath(publicPath ?? '');
  // Get public path without protocol.
  return new node_url.URL(path, 'https://127.0.0.1').pathname;
}
function getOutputPath(compilation) {
  // The `output.path` is always present and always absolute.
  const { path } = compilation.outputOptions;
  // Get the path.
  return compilation.getPath(path ?? '');
}
function getPaths(stats) {
  const paths = [];
  const childStats = getStats(stats);
  // Get the paths.
  for (const { compilation } of childStats) {
    const outputPath = getOutputPath(compilation);
    const publicPath = getPublicPath(compilation);
    // Cache paths.
    paths.push([outputPath, publicPath]);
  }
  // Return the paths.
  return paths;
}

exports.getPaths = getPaths;
