/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

'use strict';

const utils = require('../../utils.cjs');

/**
 * @module setupWatching
 */
function getWatching({ compiler, logger }) {
  const isMulti = utils.isMultiCompiler(compiler);
  if (!isMulti && compiler.watching) {
    return compiler.watching;
  }
  const errorHandler = error => {
    if (error != null) {
      // For example - `writeToDisk` can throw an error and right now it is ends watching.
      // We can improve that and keep watching active, but it is require API on webpack side.
      // Let's implement that in webpack@5 because it is rare case.
      logger.error(error);
    }
  };
  if (!isMulti) {
    const { watchOptions } = compiler.options;
    return compiler.watch(watchOptions, errorHandler);
  }
  const watchOptions = compiler.compilers.map(({ options }) => {
    return options.watchOptions;
  });
  return compiler.watch(watchOptions, errorHandler);
}
function setupWatching(context) {
  context.watching = getWatching(context);
}

exports.setupWatching = setupWatching;
