/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

'use strict';

const node_path = require('node:path');
const node_fs = require('node:fs');
const utils = require('../../utils.cjs');

/**
 * @module setupWriteToDisk
 */
function getCompilerName({ options: { name } }) {
  return `compiler ${name ? `${name}: ` : ''}`;
}
function isAllowWrite(targetPath, filter) {
  return utils.isFunction(filter) ? filter(targetPath) : filter === true;
}
function setupWriteToDisk(context) {
  const { logger, options } = context;
  const { writeToDisk: filter } = options;
  const compilers = utils.getCompilers(context.compiler);
  for (const compiler of compilers) {
    compiler.hooks.assetEmitted.tapAsync(utils.PLUGIN_NAME, (_file, { targetPath, content }, callback) => {
      if (!isAllowWrite(targetPath, filter)) {
        return callback();
      }
      const dir = node_path.dirname(targetPath);
      const name = getCompilerName(compiler);
      return node_fs.mkdir(dir, { recursive: true }, error => {
        if (error != null) {
          logger.error(`${name}unable to write "${dir}" directory to disk:\n${error}`);
          return callback(error);
        }
        node_fs.writeFile(targetPath, content, error => {
          if (error != null) {
            logger.error(`${name}unable to write "${targetPath}" asset to disk:\n${error}`);
            return callback(error);
          }
          logger.log(`${name}asset written to disk: "${targetPath}"`);
          return callback();
        });
      });
    });
  }
}

exports.setupWriteToDisk = setupWriteToDisk;
