/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

'use strict';

const node_url = require('node:url');
const utils = require('../utils.cjs');

/**
 * @module utils
 */
const BASE_URL = 'wss://127.0.0.1';
function isUpgradable({ request }) {
  const upgrade = request.get('Upgrade');
  return !!upgrade && /^websocket$/i.test(upgrade.trim());
}
function getOptions(options) {
  const settings = {
    hmr: true,
    path: '/hot',
    reload: true,
    overlay: true,
    progress: true,
    ...options
  };
  settings.path = new node_url.URL(settings.path, BASE_URL).pathname;
  return settings;
}
function hasIssues(issues) {
  return Array.isArray(issues) && issues.length > 0;
}
function getStatsOptions(compiler) {
  let statsOptions = compiler.options.stats;
  if (utils.isString(statsOptions)) {
    statsOptions = { preset: statsOptions };
  } else if (utils.isBoolean(statsOptions)) {
    statsOptions = statsOptions ? { preset: 'normal' } : { preset: 'none' };
  }
  return {
    ...statsOptions,
    all: false,
    hash: true,
    colors: true,
    errors: true,
    assets: false,
    builtAt: true,
    warnings: true,
    errorDetails: false
  };
}
function getTimestamp({ builtAt, children = [] }) {
  if (builtAt != null) {
    return builtAt;
  }
  let timestamp = -1;
  for (const { builtAt = timestamp } of children) {
    if (builtAt > timestamp) {
      timestamp = builtAt;
    }
  }
  return timestamp < 0 ? Date.now() : timestamp;
}

exports.BASE_URL = BASE_URL;
exports.getOptions = getOptions;
exports.getStatsOptions = getStatsOptions;
exports.getTimestamp = getTimestamp;
exports.hasIssues = hasIssues;
exports.isUpgradable = isUpgradable;
