/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

'use strict';

const schema = require('./schema.cjs');
const compose = require('./compose.cjs');
const utils = require('./utils.cjs');
const schemaUtils = require('schema-utils');
const index$1 = require('./hot/index.cjs');
const index = require('./dev/index.cjs');

/**
 * @module index
 */
/**
 * @function server
 * @description Create koa dev server middleware.
 * @param compiler The rspack compiler instance.
 * @param options Options.
 */
function server(compiler, options = {}) {
  schemaUtils.validate(schema.schema, options, {
    name: utils.PLUGIN_NAME,
    baseDataPath: 'options'
  });
  const { hot: hotOptions } = options;
  if (hotOptions === false) {
    return index.dev(compiler, options);
  }
  // All plugins must be initialized before watching.
  // Because dev will start watching, so call hot before dev.
  const hotMiddleware = index$1.hot(compiler, hotOptions);
  const devMiddleware = index.dev(compiler, options);
  const middleware = compose.compose(devMiddleware, hotMiddleware);
  return Object.assign(middleware, devMiddleware, hotMiddleware);
}

exports.server = server;
