/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

'use strict';

/**
 * @module utils
 */
const { toString } = Object.prototype;
const PLUGIN_NAME = 'webpack-dev-service';
function isString(value) {
  return toString.call(value) === '[object String]';
}
function isBoolean(value) {
  return toString.call(value) === '[object Boolean]';
}
function isFunction(value) {
  return typeof value === 'function';
}
function getCompilers(compiler) {
  if (isMultiCompiler(compiler)) {
    return compiler.compilers;
  }
  return [compiler];
}
function isMultiCompiler(compiler) {
  return 'compilers' in compiler;
}

exports.PLUGIN_NAME = PLUGIN_NAME;
exports.getCompilers = getCompilers;
exports.isBoolean = isBoolean;
exports.isFunction = isFunction;
exports.isMultiCompiler = isMultiCompiler;
exports.isString = isString;
