/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

import { createClient } from './client.js';

/**
 * @module main
 */
const isTLS = protocol => {
  return protocol === 'https:';
};
const getCurrentScript = () => {
  const { currentScript } = document;
  if (currentScript) {
    return currentScript;
  }
};
const getProtocol = (params, protocol) => {
  switch (params.get('wss')) {
    case 'true':
      return 'wss:';
    case 'false':
      return 'ws:';
    default:
      return isTLS(protocol) ? 'wss:' : 'ws:';
  }
};
const getOrigin = params => {
  const { location } = self;
  const script = getCurrentScript();
  if (script) {
    const url = new URL(script.src, location.href);
    const protocol = getProtocol(params, url.protocol);
    return `${protocol}//${url.host}`;
  }
  const protocol = getProtocol(params, location.protocol);
  return `${protocol}//${location.host}`;
};
const getOptions = () => {
  const params = new URLSearchParams(__resourceQuery);
  return {
    uuid: params.get('uuid'),
    origin: getOrigin(params),
    hmr: params.get('hmr') !== 'false',
    path: params.get('path') || '/hot',
    name: params.get('name') || 'rspack',
    reload: params.get('reload') !== 'false',
    overlay: params.get('overlay') !== 'false',
    progress: params.get('progress') !== 'false'
  };
};
if (document.readyState !== 'loading') {
  createClient(getOptions());
} else {
  document.addEventListener('DOMContentLoaded', () => {
    createClient(getOptions());
  });
}
