/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

/**
 * @module compose
 */
/**
 * @function dispatch
 * @description Dispatch middlewares.
 * @param middlewares The middlewares list.
 * @param index The current middleware index.
 * @param stack The call stack.
 * @param context The execution context.
 * @param next The next middleware.
 */
async function dispatch(middlewares, index, stack, context, next) {
  if (index <= stack.index) {
    throw new Error('next() called multiple times');
  }
  stack.index = index;
  const { length } = middlewares;
  if (index < length) {
    const middleware = middlewares[index];
    await middleware(context, () => {
      return dispatch(middlewares, index + 1, stack, context, next);
    });
  } else if (next) {
    await next();
  }
}
/**
 * @function compose
 * @description Compose middlewares.
 * @param middlewares The middlewares list.
 */
function compose(...middlewares) {
  /**
   * @function compose
   * @description Compose middlewares.
   * @param context The execution context.
   * @param next The next middleware.
   */
  return (context, next) => {
    const stack = { index: -1 };
    return dispatch(middlewares, 0, stack, context, next);
  };
}

export { compose };
