/**
 * @module ReadStream
 */
import { PathLike } from 'node:fs';
import { Range } from './utils/http.js';
import { FileSystem } from './utils/fs.js';
import { Readable, ReadableOptions } from 'node:stream';
export interface Options extends Pick<ReadableOptions, 'highWaterMark'> {
  fs: FileSystem;
}
interface Callback {
  (error?: Error | null): void;
}
export declare class ReadStream extends Readable {
  #private;
  /**
   * @constructor
   * @param path The file path.
   * @param ranges The ranges to read.
   * @param options The stream options.
   */
  constructor(path: PathLike, ranges: Range[], options: Options);
  /**
   * @override
   * @method _construct
   * @param callback The callback.
   */
  _construct(callback: Callback): void;
  /**
   * @override
   * @method _read
   * @param size The number of bytes to read.
   */
  _read(size: number): void;
  /**
   * @override
   * @method _destroy
   * @param error The error.
   * @param callback The callback.
   */
  _destroy(error: Error | null, callback: Callback): void;
}
export {};
