/**
 * @module Service
 */
import { Context } from 'koa';
import { Stats } from 'node:fs';
import { FileSystem } from './utils/fs.js';
interface IgnoreFunction {
  (path: string): boolean;
}
interface Headers {
  [key: string]: string | string[];
}
type FileStats = Stats | null | undefined;
interface HeadersFunction {
  (path: string, stats: FileStats): Promise<Headers | void> | Headers | void;
}
export interface Options {
  fs: FileSystem;
  etag?: boolean;
  acceptRanges?: boolean;
  lastModified?: boolean;
  highWaterMark?: number;
  ignore?: IgnoreFunction;
  headers?: Headers | HeadersFunction;
}
/**
 * @class Service
 */
export declare class Service {
  #private;
  /**
   * @constructor
   * @description Create file service.
   * @param root The file service root.
   * @param options The file service options.
   */
  constructor(root: string, options: Options);
  /**
   * @public
   * @method respond
   * @description Respond file.
   * @param pathname The pathname.
   * @param context The koa context.
   * @param publicPath The public path.
   */
  respond(pathname: string, context: Context, publicPath: string): Promise<boolean>;
}
export {};
