/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

import { ready } from './utils/ready.js';
import { createMemfs } from './utils/fs.js';
import { middleware } from './middleware.js';
import { PLUGIN_NAME } from '../utils.js';
import { setupHooks } from './utils/setupHooks.js';
import { setupWatching } from './utils/setupWatching.js';
import { setupWriteToDisk } from './utils/setupWriteToDisk.js';
import { setupOutputFileSystem } from './utils/setupOutputFileSystem.js';

/**
 * @module index
 */
function setup(compiler, options) {
  const context = {
    compiler,
    stats: null,
    callbacks: [],
    logger: compiler.getInfrastructureLogger(PLUGIN_NAME),
    options: { fs: createMemfs(), highWaterMark: 65536, ...options }
  };
  setupHooks(context);
  if (options.writeToDisk) {
    setupWriteToDisk(context);
  }
  setupOutputFileSystem(context);
  setupWatching(context);
  return context;
}
function dev(compiler, options) {
  const context = setup(compiler, options);
  return Object.assign(middleware(context), {
    get state() {
      return !!context.stats;
    },
    get logger() {
      return context.logger;
    },
    ready(callback) {
      ready(context, callback);
    },
    close(callback) {
      context.watching.close(callback);
    },
    invalidate(callback) {
      context.watching.invalidate(callback);
    }
  });
}

export { dev };
