/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

import { relative, isAbsolute } from 'node:path';

/**
 * @module path
 */
/**
 * @function unixify
 * @description Convert path to unix style.
 * @param path The path to convert.
 */
function unixify(path) {
  return path.replace(/\\/g, '/');
}
/**
 * @function hasTrailingSlash
 * @description Check if path has trailing slash.
 * @param path The path to check.
 */
function hasTrailingSlash(path) {
  return /\/$/.test(path);
}
/**
 * @function isOutRoot
 * @description Check if path is out of root.
 * @param path The path to check.
 * @param root The root path.
 */
function isOutRoot(path, root) {
  path = relative(root, path);
  return /\.\.(?:[\\/]|$)/.test(path) || isAbsolute(path);
}

export { hasTrailingSlash, isOutRoot, unixify };
