/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

import { dirname } from 'node:path';
import { mkdir, writeFile } from 'node:fs';
import { getCompilers, PLUGIN_NAME, isFunction } from '../../utils.js';

/**
 * @module setupWriteToDisk
 */
function getCompilerName({ options: { name } }) {
  return `compiler ${name ? `${name}: ` : ''}`;
}
function isAllowWrite(targetPath, filter) {
  return isFunction(filter) ? filter(targetPath) : filter === true;
}
function setupWriteToDisk(context) {
  const { logger, options } = context;
  const { writeToDisk: filter } = options;
  const compilers = getCompilers(context.compiler);
  for (const compiler of compilers) {
    compiler.hooks.assetEmitted.tapAsync(PLUGIN_NAME, (_file, { targetPath, content }, callback) => {
      if (!isAllowWrite(targetPath, filter)) {
        return callback();
      }
      const dir = dirname(targetPath);
      const name = getCompilerName(compiler);
      return mkdir(dir, { recursive: true }, error => {
        if (error != null) {
          logger.error(`${name}unable to write "${dir}" directory to disk:\n${error}`);
          return callback(error);
        }
        writeFile(targetPath, content, error => {
          if (error != null) {
            logger.error(`${name}unable to write "${targetPath}" asset to disk:\n${error}`);
            return callback(error);
          }
          logger.log(`${name}asset written to disk: "${targetPath}"`);
          return callback();
        });
      });
    });
  }
}

export { setupWriteToDisk };
