/**
 * @package webpack-dev-service
 * @license MIT
 * @version 0.15.7
 * @author nuintun <nuintun@qq.com>
 * @description A koa 2 middleware for webpack development and hot reloading.
 * @see https://github.com/nuintun/webpack-dev-service#readme
 */

import { schema } from './schema.js';
import { compose } from './compose.js';
import { PLUGIN_NAME } from './utils.js';
import { validate } from 'schema-utils';
import { hot } from './hot/index.js';
import { dev } from './dev/index.js';

/**
 * @module index
 */
/**
 * @function server
 * @description Create koa dev server middleware.
 * @param compiler The rspack compiler instance.
 * @param options Options.
 */
function server(compiler, options = {}) {
  validate(schema, options, {
    name: PLUGIN_NAME,
    baseDataPath: 'options'
  });
  const { hot: hotOptions } = options;
  if (hotOptions === false) {
    return dev(compiler, options);
  }
  // All plugins must be initialized before watching.
  // Because dev will start watching, so call hot before dev.
  const hotMiddleware = hot(compiler, hotOptions);
  const devMiddleware = dev(compiler, options);
  const middleware = compose(devMiddleware, hotMiddleware);
  return Object.assign(middleware, devMiddleware, hotMiddleware);
}

export { server };
